@@ -10,6 +10,8 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/lbaas_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
+                     '/etc/neutron/l2gw_plugin.ini',
+                     '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/cisco/cisco_plugins.ini',
                      '/etc/neutron/plugins/cisco/credentials.ini',
                      '/etc/neutron/plugins/cisco/db_conn.ini',
@@ -21,8 +23,10 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/plugins/midonet/midonet.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
                      '/etc/neutron/plugins/plumgrid/plumgrid.ini',
+                     '/etc/neutron/plugins/vmware/nsx.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf_sriov.ini',
-                     '/etc/neutron/plugins/ml2/sriov_agent.ini']
+                     '/etc/neutron/plugins/ml2/sriov_agent.ini',
+                     '/etc/neutron/plugins/ml2/vpp_agent.ini']
 
   pp= <<-EOS
   Exec { logoutput => 'on_failure' }
@@ -42,6 +46,7 @@ describe 'basic neutron_config resource' do
   File <||> -> Neutron_plugin_linuxbridge <||>
   File <||> -> Neutron_plugin_ml2 <||>
   File <||> -> Neutron_plugin_nvp <||>
+  File <||> -> Neutron_l2gw_service_config <||>
   File <||> -> Neutron_vpnaas_agent_config <||>
   File <||> -> Neutron_plugin_midonet <||>
   File <||> -> Neutron_plugin_opencontrail <||>
@@ -51,6 +56,10 @@ describe 'basic neutron_config resource' do
   File <||> -> Neutron_plumlib_plumgrid <||>
   File <||> -> Neutron_plugin_sriov <||>
   File <||> -> Neutron_sriov_agent_config <||>
+  File <||> -> Neutron_agent_vpp <||>
+  File <||> -> Neutron_l2gw_agent_config <||>
+  File <||> -> Neutron_plugin_nsx <||>
+
 
   $neutron_directories = ['/etc/neutron',
                           '/etc/neutron/plugins',
@@ -60,7 +69,8 @@ describe 'basic neutron_config resource' do
                           '/etc/neutron/plugins/nicira',
                           '/etc/neutron/plugins/midonet',
                           '/etc/neutron/plugins/opencontrail',
-                          '/etc/neutron/plugins/plumgrid']
+                          '/etc/neutron/plugins/plumgrid',
+                          '/etc/neutron/plugins/vmware']
 
   $neutron_files = [ '/etc/neutron/api-paste.ini',
                      '/etc/neutron/neutron.conf',
@@ -70,6 +80,8 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/lbaas_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
+                     '/etc/neutron/l2gw_plugin.ini',
+                     '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/cisco/cisco_plugins.ini',
                      '/etc/neutron/plugins/cisco/credentials.ini',
                      '/etc/neutron/plugins/cisco/db_conn.ini',
@@ -81,8 +93,10 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/plugins/midonet/midonet.ini',
                      '/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
                      '/etc/neutron/plugins/plumgrid/plumgrid.ini',
+                     '/etc/neutron/plugins/vmware/nsx.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf_sriov.ini',
-                     '/etc/neutron/plugins/ml2/sriov_agent.ini']
+                     '/etc/neutron/plugins/ml2/sriov_agent.ini',
+                     '/etc/neutron/plugins/ml2/vpp_agent.ini']
 
   file { $neutron_directories :
     ensure => directory,
@@ -486,6 +500,24 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
+  neutron_plugin_nsx { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_plugin_nsx { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_plugin_nsx { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_plugin_nsx { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
   neutron_plugin_sriov { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -522,6 +554,60 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
+  neutron_agent_vpp { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_agent_vpp { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_agent_vpp { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_agent_vpp { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_l2gw_service_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_l2gw_service_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_l2gw_service_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_l2gw_service_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_l2gw_agent_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_l2gw_agent_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_l2gw_agent_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_l2gw_agent_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
   EOS
 
   resource_names = ['neutron_api_config',
@@ -546,7 +632,10 @@ describe 'basic neutron_config resource' do
                     'neutron_agent_ovs',
                     'neutron_plugin_plumgrid',
                     'neutron_plugin_sriov',
-                    'neutron_sriov_agent_config']
+                    'neutron_sriov_agent_config',
+                    'neutron_agent_vpp',
+                    'neutron_l2gw_service_config',
+                    'neutron_l2gw_agent_config']
 
   pp_resource_names = "  $resource_names = [" + resource_names.collect { |r| "    '#{r}'," }.join("\n") + "   ]\n"
 
