@@ -16,7 +16,6 @@ describe 'neutron::agents::dhcp' do
       :state_path               => '/var/lib/neutron',
       :resync_interval          => 30,
       :interface_driver         => 'neutron.agent.linux.interface.OVSInterfaceDriver',
-      :dhcp_driver              => 'neutron.agent.linux.dhcp.Dnsmasq',
       :root_helper              => 'sudo neutron-rootwrap /etc/neutron/rootwrap.conf',
       :enable_isolated_metadata => false,
       :enable_metadata_network  => false,
@@ -36,21 +35,25 @@ describe 'neutron::agents::dhcp' do
 
     it { is_expected.to contain_class('neutron::params') }
 
-    it_configures 'dnsmasq dhcp_driver'
-
     it 'configures dhcp_agent.ini' do
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/state_path').with_value(p[:state_path]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/resync_interval').with_value(p[:resync_interval]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>');
-      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_driver').with_value(p[:dhcp_driver]);
+      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_driver').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/root_helper').with_value(p[:root_helper]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/enable_isolated_metadata').with_value(p[:enable_isolated_metadata]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/force_metadata').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/enable_metadata_network').with_value(p[:enable_metadata_network]);
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dhcp_broadcast_reply').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_local_resolv').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_dhcp_agent_config('AGENT/availability_zone').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('OVS/ovsdb_connection').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_key_file').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_cert_file').with_value('<SERVICE DEFAULT>');
+      is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_ca_cert_file').with_value('<SERVICE DEFAULT>');
     end
 
     it 'installs neutron dhcp agent package' do
@@ -152,6 +155,34 @@ describe 'neutron::agents::dhcp' do
         is_expected.to contain_neutron_dhcp_agent_config('AGENT/availability_zone').with_value(p[:availability_zone]);
       end
     end
+
+    context 'with SSL configuration' do
+      before do
+        params.merge!({
+          :ovsdb_connection          => 'ssl:127.0.0.1:6639',
+          :ovsdb_agent_ssl_key_file  => '/tmp/dummy.pem',
+          :ovsdb_agent_ssl_cert_file => '/tmp/dummy.crt',
+          :ovsdb_agent_ssl_ca_file   => '/tmp/ca.crt'
+        })
+      end
+      it 'configures neutron SSL settings' do
+        is_expected.to contain_neutron_dhcp_agent_config('OVS/ovsdb_connection').with_value(params[:ovsdb_connection])
+        is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_key_file').with_value(params[:ovsdb_agent_ssl_key_file])
+        is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_cert_file').with_value(params[:ovsdb_agent_ssl_cert_file])
+        is_expected.to contain_neutron_dhcp_agent_config('OVS/ssl_ca_cert_file').with_value(params[:ovsdb_agent_ssl_ca_file])
+      end
+    end
+
+    context 'with SSL enabled, but missing file config' do
+      before do
+        params.merge!({
+          :ovsdb_connection => 'ssl:127.0.0.1:6639'
+        })
+      end
+      it 'fails to configure' do
+        is_expected.to raise_error(Puppet::Error)
+      end
+    end
   end
 
   shared_examples_for 'neutron dhcp agent with dnsmasq_config_file specified' do
@@ -165,6 +196,17 @@ describe 'neutron::agents::dhcp' do
     end
   end
 
+  shared_examples_for 'enable advertisement of the DNS resolver on the host.' do
+    before do
+      params.merge!(
+        :dnsmasq_local_resolv => true
+      )
+    end
+    it 'configures dnsmasq_local_resolv' do
+      is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/dnsmasq_local_resolv').with_value(params[:dnsmasq_config_file])
+    end
+  end
+
   shared_examples_for 'neutron dhcp agent with dnsmasq_dns_servers set' do
     before do
       params.merge!(
@@ -176,24 +218,6 @@ describe 'neutron::agents::dhcp' do
     end
   end
 
-  shared_examples_for 'dnsmasq dhcp_driver' do
-    it 'installs dnsmasq packages' do
-      if platform_params.has_key?(:dhcp_agent_package)
-        is_expected.to contain_package(platform_params[:dnsmasq_base_package]).with_before(['Package[neutron-dhcp-agent]'])
-        is_expected.to contain_package(platform_params[:dnsmasq_utils_package]).with_before(['Package[neutron-dhcp-agent]'])
-      end
-      is_expected.to contain_package(platform_params[:dnsmasq_base_package]).with(
-        :ensure => 'present',
-        :name   => platform_params[:dnsmasq_base_package]
-      )
-      is_expected.to contain_package(platform_params[:dnsmasq_utils_package]).with(
-        :ensure => 'present',
-        :name   => platform_params[:dnsmasq_utils_package]
-      )
-    end
-  end
-
-
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
@@ -202,9 +226,7 @@ describe 'neutron::agents::dhcp' do
     end
 
     let :platform_params do
-      { :dnsmasq_base_package  => 'dnsmasq-base',
-        :dnsmasq_utils_package => 'dnsmasq-utils',
-        :dhcp_agent_package    => 'neutron-dhcp-agent',
+      { :dhcp_agent_package    => 'neutron-dhcp-agent',
         :dhcp_agent_service    => 'neutron-dhcp-agent' }
     end
 
@@ -225,9 +247,7 @@ describe 'neutron::agents::dhcp' do
     end
 
     let :platform_params do
-      { :dnsmasq_base_package  => 'dnsmasq',
-        :dnsmasq_utils_package => 'dnsmasq-utils',
-        :dhcp_agent_service    => 'neutron-dhcp-agent' }
+      { :dhcp_agent_service    => 'neutron-dhcp-agent' }
     end
 
     it_configures 'neutron dhcp agent'
