@@ -7,20 +7,19 @@ describe 'neutron::agents::l3' do
   end
 
   let :default_params do
-    { :package_ensure                   => 'present',
-      :enabled                          => true,
-      :debug                            => false,
-      :interface_driver                 => 'neutron.agent.linux.interface.OVSInterfaceDriver',
-      :ha_enabled                       => false,
-      :ha_vrrp_auth_type                => 'PASS',
-      :ha_vrrp_advert_int               => '3',
-      :agent_mode                       => 'legacy',
-      :purge_config                     => false }
+    { :package_ensure     => 'present',
+      :enabled            => true,
+      :interface_driver   => 'neutron.agent.linux.interface.OVSInterfaceDriver',
+      :ha_enabled         => false,
+      :ha_vrrp_auth_type  => 'PASS',
+      :ha_vrrp_advert_int => '3',
+      :agent_mode         => 'legacy',
+      :purge_config       => false }
   end
 
   let :test_facts do
-    { :operatingsystem           => 'default',
-      :operatingsystemrelease    => 'default'
+    { :operatingsystem        => 'default',
+      :operatingsystemrelease => 'default'
     }
   end
 
@@ -36,8 +35,7 @@ describe 'neutron::agents::l3' do
     it { is_expected.to contain_class('neutron::params') }
 
     it 'configures l3_agent.ini' do
-      is_expected.to contain_neutron_l3_agent_config('DEFAULT/debug').with_value(p[:debug])
-      is_expected.to contain_neutron_l3_agent_config('DEFAULT/external_network_bridge').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_l3_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver])
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/gateway_external_network_id').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/handle_internal_only_routers').with_value('<SERVICE DEFAULT>')
@@ -47,6 +45,7 @@ describe 'neutron::agents::l3' do
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/periodic_fuzzy_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('DEFAULT/enable_metadata_proxy').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_l3_agent_config('AGENT/availability_zone').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_l3_agent_config('AGENT/extensions').with_value('<SERVICE DEFAULT>')
     end
 
     it 'passes purge to resource' do
