@@ -13,7 +13,8 @@ describe 'neutron::agents::ml2::linuxbridge' do
       :tunnel_types                => [],
       :local_ip                    => false,
       :physical_interface_mappings => [],
-      :firewall_driver             => 'neutron.agent.linux.iptables_firewall.IptablesFirewallDriver',
+      :bridge_mappings             => [],
+      :firewall_driver             => 'iptables',
       :purge_config                => false,}
   end
 
@@ -41,6 +42,7 @@ describe 'neutron::agents::ml2::linuxbridge' do
       it 'configures ml2_conf.ini' do
         is_expected.to contain_neutron_agent_linuxbridge('agent/polling_interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_neutron_agent_linuxbridge('linux_bridge/physical_interface_mappings').with_value(default_params[:physical_interface_mappings].join(','))
+        is_expected.to contain_neutron_agent_linuxbridge('linux_bridge/bridge_mappings').with_ensure('absent')
         is_expected.to contain_neutron_agent_linuxbridge('securitygroup/firewall_driver').with_value(default_params[:firewall_driver])
         is_expected.to contain_neutron_agent_linuxbridge('agent/tunnel_types').with_ensure('absent')
       end
@@ -98,11 +100,10 @@ describe 'neutron::agents::ml2::linuxbridge' do
 
       context 'when providing all parameters' do
         it 'configures ml2_conf.ini' do
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/enable_vxlan').with_value(true)
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/local_ip').with_value(params[:local_ip])
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_group').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_ttl').with_value('<SERVICE DEFAULT>')
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_tos').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_neutron_agent_linuxbridge('vxlan/ttl').with_value('<SERVICE DEFAULT>')
+          is_expected.to contain_neutron_agent_linuxbridge('vxlan/tos').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/l2_population').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_neutron_agent_linuxbridge('agent/tunnel_types').with_value(params[:tunnel_types])
         end
@@ -119,11 +120,10 @@ describe 'neutron::agents::ml2::linuxbridge' do
         end
 
         it 'configures ml2_conf.ini' do
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/enable_vxlan').with_value(true)
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/local_ip').with_value(params[:local_ip])
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_group').with_value(params[:vxlan_group])
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_ttl').with_value(params[:vxlan_ttl])
-          is_expected.to contain_neutron_agent_linuxbridge('vxlan/vxlan_tos').with_value(params[:vxlan_tos])
+          is_expected.to contain_neutron_agent_linuxbridge('vxlan/ttl').with_value(params[:vxlan_ttl])
+          is_expected.to contain_neutron_agent_linuxbridge('vxlan/tos').with_value(params[:vxlan_tos])
           is_expected.to contain_neutron_agent_linuxbridge('vxlan/l2_population').with_value(params[:l2_population])
         end
       end
@@ -141,6 +141,18 @@ describe 'neutron::agents::ml2::linuxbridge' do
       end
     end
 
+    context 'when providing the bridge_mappings parameter' do
+      before do
+        params.merge!(:bridge_mappings => ['physnet0:br0', 'physnet1:br1'])
+      end
+
+      it 'configures bridge mappings' do
+        is_expected.to contain_neutron_agent_linuxbridge('linux_bridge/bridge_mappings').with_value(
+          params[:bridge_mappings].join(',')
+        )
+      end
+    end
+
     context 'with firewall_driver parameter set to false' do
       before :each do
         params.merge!(:firewall_driver => false)
