@@ -14,6 +14,8 @@ describe 'neutron::config' do
       { :server_config => config_hash }
     end
 
+    it { is_expected.to contain_class('neutron::deps') }
+
     it 'configures arbitrary neutron-config configurations' do
       is_expected.to contain_neutron_config('DEFAULT/foo').with_value('fooValue')
       is_expected.to contain_neutron_config('DEFAULT/bar').with_value('barValue')
@@ -33,13 +35,35 @@ describe 'neutron::config' do
     end
   end
 
+  shared_examples_for 'neutron_service_config' do
+    let :params do
+      { :sfc_service_config  => config_hash,
+        :l2gw_service_config => config_hash,
+      }
+    end
+
+    it 'configures arbitrary sfc_service_config configurations' do
+      is_expected.to contain_neutron_sfc_service_config('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_sfc_service_config('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_sfc_service_config('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary l2gw_service_config configurations' do
+      is_expected.to contain_neutron_l2gw_service_config('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_l2gw_service_config('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_l2gw_service_config('DEFAULT/baz').with_ensure('absent')
+    end
+  end
+
   shared_examples_for 'neutron_agent_config' do
     let :params do
-      { :l3_agent_config        => config_hash,
-        :dhcp_agent_config      => config_hash,
-        :metadata_agent_config  => config_hash,
-        :metering_agent_config  => config_hash,
-        :vpnaas_agent_config    => config_hash,
+      { :l3_agent_config       => config_hash,
+        :dhcp_agent_config     => config_hash,
+        :lbaas_agent_config    => config_hash,
+        :metadata_agent_config => config_hash,
+        :metering_agent_config => config_hash,
+        :vpnaas_agent_config   => config_hash,
+        :l2gw_agent_config     => config_hash,
       }
     end
 
@@ -55,6 +79,12 @@ describe 'neutron::config' do
       is_expected.to contain_neutron_dhcp_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary lbaas_agent_config configurations' do
+      is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary metadata_agent_config configurations' do
       is_expected.to contain_neutron_metadata_agent_config('DEFAULT/foo').with_value('fooValue')
       is_expected.to contain_neutron_metadata_agent_config('DEFAULT/bar').with_value('barValue')
@@ -73,6 +103,12 @@ describe 'neutron::config' do
       is_expected.to contain_neutron_vpnaas_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary l2gw_agent_config configurations' do
+      is_expected.to contain_neutron_l2gw_agent_config('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_l2gw_agent_config('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_l2gw_agent_config('DEFAULT/baz').with_ensure('absent')
+    end
+
   end
 
   shared_examples_for 'neutron_plugin_config' do
@@ -84,6 +120,8 @@ describe 'neutron::config' do
         :plugin_cisco_config           => config_hash,
         :plugin_midonet_config         => config_hash,
         :plugin_plumgrid_config        => config_hash,
+        :plugin_nsx_config             => config_hash,
+        :plugin_nvp_config             => config_hash,
         :plugin_opencontrail_config    => config_hash,
         :plugin_nuage_config           => config_hash,
         :plugin_ml2_config             => config_hash
@@ -126,6 +164,18 @@ describe 'neutron::config' do
       is_expected.to contain_neutron_plugin_plumgrid('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary neutron_plugin_nsx configurations' do
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary neutron_plugin_nvp configurations' do
+      is_expected.to contain_neutron_plugin_nvp('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_plugin_nvp('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_plugin_nvp('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary neutron_plugin_opencontrail configurations' do
       is_expected.to contain_neutron_plugin_opencontrail('DEFAULT/foo').with_value('fooValue')
       is_expected.to contain_neutron_plugin_opencontrail('DEFAULT/bar').with_value('barValue')
