@@ -4,7 +4,7 @@ describe 'neutron' do
 
   let :params do
     { :package_ensure        => 'present',
-      :core_plugin           => 'linuxbridge',
+      :core_plugin           => 'ml2',
       :auth_strategy         => 'keystone',
       :rabbit_password       => 'guest',
       :log_dir               => '/var/log/neutron',
@@ -52,9 +52,9 @@ describe 'neutron' do
       end
 
       it 'configures logging' do
-        is_expected.to contain_neutron_config('DEFAULT/log_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_neutron_config('DEFAULT/log_dir').with_value(params[:log_dir])
-        is_expected.to contain_neutron_config('DEFAULT/use_stderr').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__log('neutron_config').with(:log_file   => '<SERVICE DEFAULT>',
+                                                                :log_dir    => params[:log_dir],
+                                                                :use_stderr => '<SERVICE DEFAULT>')
       end
 
     end
@@ -87,14 +87,13 @@ describe 'neutron' do
     it_configures 'with log_file specified'
     it_configures 'without service_plugins'
     it_configures 'with service_plugins'
-    it_configures 'without memcache_servers'
-    it_configures 'with memcache_servers'
     it_configures 'with host defined'
     it_configures 'with dns_domain defined'
     it_configures 'with transport_url defined'
     it_configures 'with rootwrap daemon'
+    it_configures 'with max_allowed_address_pair defined'
 
-    context 'with amqp rpc_backend value' do
+    context 'with amqp messaging' do
       it_configures 'amqp support'
     end
   end
@@ -142,7 +141,6 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/auth_strategy').with_value('keystone')
       is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value( params[:core_plugin] )
       is_expected.to contain_neutron_config('DEFAULT/base_mac').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/mac_generation_retries').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_lease_duration').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dns_domain').with_value('<SERVICE DEFAULT>')
@@ -314,13 +312,13 @@ describe 'neutron' do
       )
     end
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => true,
+      :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+      :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+      :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+      :kombu_ssl_version  => 'TLSv1'
+    )}
   end
 
   shared_examples_for 'with SSL enabled without kombu' do
@@ -330,24 +328,16 @@ describe 'neutron' do
       )
     end
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => true,
+    )}
   end
 
   shared_examples_for 'with SSL disabled' do
 
-    it do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('neutron_config').with(
+      :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+    )}
   end
 
   shared_examples_for 'with SSL and kombu wrongly configured' do
@@ -422,23 +412,6 @@ describe 'neutron' do
 
   end
 
-  shared_examples_for 'without memcache_servers' do
-    it { is_expected.to contain_neutron_config('DEFAULT/memcached_servers').with_ensure('absent') }
-  end
-
-  shared_examples_for 'with memcache_servers' do
-    before do
-      params.merge!(
-        :memcache_servers => ['memcache1','memcache2','memcache3']
-      )
-    end
-
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/memcached_servers').with_value('memcache1,memcache2,memcache3')
-    end
-
-  end
-
   shared_examples_for 'with global_physnet_mtu defined' do
     before do
       params.merge!(
@@ -500,10 +473,7 @@ describe 'neutron' do
   end
 
   shared_examples_for 'amqp support' do
-    context 'with default parameters' do
-      before { params.merge!( :rpc_backend => 'amqp' ) }
-
-      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
+    context 'with default amqp parameters' do
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -522,9 +492,8 @@ describe 'neutron' do
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
     end
 
-    context 'with overriden amqp parameters' do
+    context 'with overridden amqp parameters' do
       before { params.merge!(
-        :rpc_backend        => 'amqp',
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
         :amqp_ssl_ca_file   => '/path/to/ca.cert',
@@ -534,7 +503,6 @@ describe 'neutron' do
         :amqp_password      => 'password',
       ) }
 
-      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -553,6 +521,18 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'with max_allowed_address_pair defined' do
+    before do
+      params.merge!(
+        :max_allowed_address_pair => '50'
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('DEFAULT/max_allowed_address_pair').with_value(params[:max_allowed_address_pair])
+    end
+  end
+
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
