@@ -3,10 +3,13 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::bigswitch' do
 
   let :pre_condition do
-    "class { 'neutron::server': password => 'password'}
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
      class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :default_params do
