@@ -3,23 +3,30 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::opendaylight' do
 
   let :pre_condition do
-    "class { 'neutron::server': password => 'password'}
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
      class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
+      core_plugin     => 'ml2' }"
   end
 
   let :default_params do
     {
-      :package_ensure => 'present',
-      :odl_username   => '<SERVICE DEFAULT>',
-      :odl_password   => '<SERVICE DEFAULT>',
-      :odl_url        => '<SERVICE DEFAULT>',
+      :package_ensure          => 'present',
+      :odl_url                 => '<SERVICE DEFAULT>',
+      :ovsdb_connection        => 'tcp:127.0.0.1:6639',
+      :port_binding_controller => '<SERVICE DEFAULT>',
+      :odl_hostconf_uri        => '<SERVICE DEFAULT>',
+      :odl_features            => '<SERVICE DEFAULT>',
     }
   end
 
   let :params do
     {
+      :odl_username           => 'user',
+      :odl_password           => 'password',
     }
   end
 
@@ -44,9 +51,16 @@ describe 'neutron::plugins::ml2::opendaylight' do
     end
 
     it 'configures ml2_odl settings' do
-      is_expected.to contain_neutron_plugin_ml2('ml2_odl/password').with_value(params[:odl_password])
+      is_expected.to contain_neutron_plugin_ml2('ml2_odl/password').with_value(params[:odl_password]).with_secret(true)
       is_expected.to contain_neutron_plugin_ml2('ml2_odl/username').with_value(params[:odl_username])
       is_expected.to contain_neutron_plugin_ml2('ml2_odl/url').with_value(params[:odl_url])
+      is_expected.to contain_neutron_plugin_ml2('ml2_odl/port_binding_controller').with_value(params[:port_binding_controller])
+      is_expected.to contain_neutron_plugin_ml2('ml2_odl/odl_hostconf_uri').with_value(params[:odl_hostconf_uri])
+      is_expected.to contain_neutron_plugin_ml2('ml2_odl/odl_features').with_value(params[:odl_features])
+    end
+
+    it 'configures neutron server settings' do
+      is_expected.to contain_neutron_config('OVS/ovsdb_connection').with_value(params[:ovsdb_connection])
     end
   end
 
