@@ -3,7 +3,10 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::ovn' do
 
   let :pre_condition do
-    "class { 'neutron::server': password => 'password' }
+    "class { '::neutron::keystone::authtoken':
+      password => 'passw0rd',
+     }
+     class { 'neutron::server': }
      class { 'neutron': rabbit_password => 'passw0rd' }"
   end
 
@@ -15,6 +18,7 @@ describe 'neutron::plugins::ml2::ovn' do
        :neutron_sync_mode        => 'log',
        :ovn_l3_mode              => true,
        :vif_type                 => 'ovs',
+       :dvr_enabled              => false,
     }
   end
 
@@ -35,12 +39,13 @@ describe 'neutron::plugins::ml2::ovn' do
     end
 
     it 'should perform default configuration of' do
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/vif_type').with_value(params[:vif_type])
+      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
+      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
+      is_expected.to contain_neutron_plugin_ml2('ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
+      is_expected.to contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
+      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
+      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value(params[:vif_type])
+      is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
     end
 
   end
@@ -64,7 +69,16 @@ describe 'neutron::plugins::ml2::ovn' do
       params[:vif_type] = 'invalid'
       is_expected.to raise_error(Puppet::Error, /Invalid value for vif_type parameter/)
       params.delete(:vif_type)
-      is_expected.to contain_neutron_plugin_ml2('ml2_ovn/vif_type').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value('<SERVICE DEFAULT>')
+    end
+
+    context 'with DVR' do
+      before :each do
+        params.merge!(:dvr_enabled => true)
+      end
+      it 'should enable DVR mode' do
+        is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+      end
     end
   end
 
