@@ -5,8 +5,11 @@ describe 'neutron::plugins::nuage' do
   let :pre_condition do
     "class { 'neutron':
       rabbit_password => 'passw0rd',
-      core_plugin     => 'neutron.plugins.nuage.plugin.NuagePlugin' }
-     class { 'neutron::server': password => 'password' }"
+      core_plugin     => 'nuage_neutron.plugins.nuage.plugin.NuagePlugin' }
+      class { '::neutron::keystone::authtoken':
+        password => 'passw0rd',
+      }
+      class { 'neutron::server': }"
   end
 
   let :test_facts do
@@ -41,7 +44,7 @@ describe 'neutron::plugins::nuage' do
     end
 
     it 'should configure neutron.conf' do
-      is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value('neutron.plugins.nuage.plugin.NuagePlugin')
+      is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value('nuage_neutron.plugins.nuage.plugin.NuagePlugin')
     end
 
     it 'passes purge to resource' do
@@ -129,4 +132,3 @@ describe 'neutron::plugins::nuage' do
   end
 
 end
-
