@@ -3,22 +3,20 @@ require 'spec_helper'
 describe 'neutron::server' do
 
   let :pre_condition do
-    "class { 'neutron': rabbit_password => 'passw0rd' }"
+    "class { 'neutron': rabbit_password => 'passw0rd' }
+     class { '::neutron::keystone::authtoken':
+       password => 'passw0rd',
+     }"
   end
 
   let :params do
-    { :password            => 'passw0rd',
-      :username            => 'neutron',
-      :keystone_auth_type  => 'password',
-      :project_domain_name => 'Default',
-      :project_name        => 'services',
-      :user_domain_name    => 'Default'}
+    {}
   end
 
   let :default_params do
     { :package_ensure                   => 'present',
       :enabled                          => true,
-      :auth_type                        => 'keystone',
+      :auth_strategy                    => 'keystone',
       :database_connection              => 'sqlite:////var/lib/neutron/ovs.sqlite',
       :database_max_retries             => 10,
       :database_idle_timeout            => 3600,
@@ -68,17 +66,22 @@ describe 'neutron::server' do
         :name    => platform_params[:server_service],
         :enable  => true,
         :ensure  => 'running',
-        :tag     => ['neutron-service', 'neutron-db-sync-service'],
+        :tag     => ['neutron-service', 'neutron-db-sync-service', 'neutron-server-eventlet'],
       )
       is_expected.to contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
       is_expected.to contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
       is_expected.not_to contain_class('neutron::db::sync')
       is_expected.to contain_service('neutron-server').with_name('neutron-server')
-      is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:processorcount])
-      is_expected.to contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:processorcount])
+      is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
+      is_expected.to contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
       is_expected.to contain_neutron_config('DEFAULT/agent_down_time').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('DEFAULT/enable_new_agents').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/router_scheduler_driver').with_value(p[:router_scheduler_driver])
       is_expected.to contain_neutron_config('qos/notification_drivers').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_oslo__middleware('neutron_config').with(
+        :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+      )
+      is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -90,15 +93,24 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with DVR enabled' do
+    context 'with DVR enabled for new routers' do
       before :each do
         params.merge!(:router_distributed => true)
       end
-      it 'should enable DVR' do
+      it 'should enable DVR for new routers' do
         is_expected.to contain_neutron_config('DEFAULT/router_distributed').with_value(true)
       end
     end
 
+    context 'with DVR disabled' do
+      before :each do
+        params.merge!(:enable_dvr => false)
+      end
+      it 'should disable DVR' do
+        is_expected.to contain_neutron_config('DEFAULT/enable_dvr').with_value(false)
+      end
+    end
+
     context 'with HA routers enabled' do
       before :each do
         params.merge!(:l3_ha => true)
@@ -131,15 +143,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with custom service name' do
-      before :each do
-        params.merge!(:service_name => 'custom-service-name')
-      end
-      it 'should configure proper service name' do
-        is_expected.to contain_service('neutron-server').with_name('custom-service-name')
-      end
-    end
-
     context 'with state_path and lock_path parameters' do
       before :each do
         params.merge!(:state_path => 'state_path',
@@ -217,13 +220,63 @@ describe 'neutron::server' do
       end
 
     end
-  end
 
-  shared_examples_for 'a neutron server with broken authentication' do
-    before do
-      params.delete(:password)
+    context 'with enable_proxy_headers_parsing' do
+      before :each do
+        params.merge!({:enable_proxy_headers_parsing => true })
+      end
+
+      it { is_expected.to contain_oslo__middleware('neutron_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
     end
-    it_raises 'a Puppet::Error', /Please set password for neutron service user/
+
+    context 'when running neutron-api in wsgi' do
+      before :each do
+        params.merge!({ :service_name => 'httpd' })
+      end
+
+      let :pre_condition do
+        "class { 'neutron': rabbit_password => 'passw0rd' }
+         include ::apache
+         class { '::neutron::keystone::authtoken':
+           password => 'passw0rd',
+         }"
+      end
+
+      it 'configures neutron-api service with Apache' do
+        is_expected.to contain_service('neutron-server').with(
+          :ensure     => 'stopped',
+          :name       => platform_params[:server_service],
+          :enable     => false,
+          :tag        => ['neutron-service', 'neutron-db-sync-service'],
+        )
+      end
+    end
+
+    context 'when service_name is customized' do
+      before :each do
+        params.merge!({ :service_name => 'foobar' })
+      end
+
+      it 'configures neutron-api service with custom name' do
+        is_expected.to contain_service('neutron-server').with(
+          :name    => 'foobar',
+          :enable  => true,
+          :ensure  => 'running',
+          :tag     => ['neutron-service', 'neutron-db-sync-service'],
+        )
+      end
+    end
+
+    context 'with ovs_integration_bridge set' do
+      before :each do
+        params.merge!({:ovs_integration_bridge => 'br-int' })
+      end
+
+      it { is_expected.to contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
+    end
+
   end
 
   shared_examples_for 'VPNaaS, FWaaS and LBaaS package installation' do
@@ -255,8 +308,7 @@ describe 'neutron::server' do
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
-         :osfamily => 'Debian',
-         :processorcount => '2'
+         :osfamily       => 'Debian',
       }))
     end
 
@@ -266,7 +318,6 @@ describe 'neutron::server' do
     end
 
     it_configures 'a neutron server'
-    it_configures 'a neutron server with broken authentication'
     it_configures 'a neutron server without database synchronization'
   end
 
@@ -275,7 +326,6 @@ describe 'neutron::server' do
       @default_facts.merge(test_facts.merge({
           :osfamily               => 'RedHat',
           :operatingsystemrelease => '7',
-          :processorcount         => '2'
       }))
     end
 
@@ -284,7 +334,6 @@ describe 'neutron::server' do
     end
 
     it_configures 'a neutron server'
-    it_configures 'a neutron server with broken authentication'
     it_configures 'a neutron server without database synchronization'
   end
 end
