@@ -22,7 +22,7 @@ describe 'neutron::services::vpnaas' do
 
   let :default_params do
     { :package_ensure    => 'present',
-      :service_providers => '<SERVICE_DEFAULT>'}
+      :service_providers => '<SERVICE DEFAULT>'}
   end
 
   shared_examples_for 'neutron vpnaas service plugin' do
